///File : DialogDevisPrices.cpp
//------------------------------------------------------------------------------
/*
    This file is part of DevisMaker.

    DevisMaker is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DevisMaker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DevisMaker.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "DialogDevisPrices.hpp"
//------------------------------------------------------------------------------

DialogDevisPrices::DialogDevisPrices( wxWindow* parent, wxWindowID id, DevisManager *devisManager, const wxString& title, const wxPoint& pos, const wxSize& size, long style ) : wxDialog( parent, id, title, pos, size, style )
{
    // Devis Manager
    m_DevisManager = devisManager;

    	// Les tableau
	std::vector<double> tblValues;
    std::vector<wxString> tblStrs;
    std::vector<bool> tblSeparation;

    if(m_DevisManager->GetDevisCfg()->GetBool("isDumpCharges") || m_DevisManager->GetDevisCfg()->GetBool("isPort"))
    {
        tblStrs.push_back(_("Total sections price (HT) :"));
        tblValues.push_back(m_DevisManager->GetSectionsPriceHT());
        tblSeparation.push_back(false);

        if(m_DevisManager->GetDevisCfg()->GetBool("isPort"))
        {
            tblStrs.push_back(_("Dump charge :"));
            tblValues.push_back(m_DevisManager->GetDumpChargeHT());
            tblSeparation.push_back(false);
        }

        if(m_DevisManager->GetDevisCfg()->GetBool("isDumpCharges"))
        {
            tblStrs.push_back(_("Port charges :"));
            tblValues.push_back(m_DevisManager->GetPortHT());
            tblSeparation.push_back(false);
        }
    }

    tblStrs.push_back(_("Total Brut (HT) :"));
    tblValues.push_back(m_DevisManager->GetTotalBrutHT());
    tblSeparation.push_back(m_DevisManager->GetDevisCfg()->GetBool("isDumpCharges") || m_DevisManager->GetDevisCfg()->GetBool("isPort"));

    tblStrs.push_back(_("Discount rate price :"));
    tblValues.push_back(m_DevisManager->GetPriceDiscountRateHT());
    tblSeparation.push_back(false);

    tblStrs.push_back(_("Discount :"));
    tblValues.push_back(m_DevisManager->GetDiscountHT());
    tblSeparation.push_back(false);

    tblStrs.push_back(_("Total net (HT) :"));
    tblValues.push_back(m_DevisManager->GetTotalNetHT());
    tblSeparation.push_back(true);

    if(m_DevisManager->GetDevisCfg()->GetBool("isEcoPart"))
    {
        tblStrs.push_back(_("\tWith Eco Part :"));
        tblValues.push_back(m_DevisManager->GetEcoPartTotalPrice());
        tblSeparation.push_back(false);
    }

    tblStrs.push_back(_("TVA :"));
    tblValues.push_back(m_DevisManager->GetTVAPrice());
    tblSeparation.push_back(false);

    tblStrs.push_back(_("Total (TTC) :"));
    tblValues.push_back(m_DevisManager->GetTotalTTC());
    tblSeparation.push_back(false);

    tblStrs.push_back(_("Payment on :"));
    tblValues.push_back(m_DevisManager->GetPaymentOn());
    tblSeparation.push_back(false);

    tblStrs.push_back(_("Total to pay :"));
    tblValues.push_back(m_DevisManager->GetTotalToPay());
    tblSeparation.push_back(true);

    // Ctrl

    wxBoxSizer* MainSizer = new wxBoxSizer( wxVERTICAL );

    for(int i = 0; i <  tblStrs.size(); i++)
    {
        if(tblSeparation[i]) // Lines
        {
            MainSizer->Add(new wxStaticLine(this, wxID_ANY), 0, wxEXPAND | wxALL, 5);
        }

        wxBoxSizer *sizer = new wxBoxSizer( wxHORIZONTAL );
        sizer->Add(new wxStaticText(this, wxID_ANY, tblStrs[i], wxDefaultPosition, wxSize(300, -1)), 0, wxALIGN_CENTER_VERTICAL | wxALL, 5 );
        sizer->AddStretchSpacer();// ==> Prends le plus de place possible ==> Nb à droite
        sizer->Add(new wxStaticText(this, wxID_ANY, ArrangePrice(tblValues[i], &m_DevisManager->GetGeneralCfg()->GetGeneralCfg())), 0, wxALL, 5 );
        MainSizer->Add(sizer, 1,wxEXPAND);
    }

	wxSizer *btnSizer=CreateButtonSizer(wxOK);
	MainSizer->Add(btnSizer,0,wxALIGN_RIGHT | wxALL | wxEXPAND,5);

	SetSizer( MainSizer );
	MainSizer->Fit(this);

	CenterOnParent();
}
//------------------------------------------------------------------------------
